@@ -13,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
 from google.type import dayofweek_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.metastore.v1",
@@ -82,7 +80,7 @@ class Service(proto.Message):
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time when the metastore
             service was last updated.
-        labels (Sequence[google.cloud.metastore_v1.types.Service.LabelsEntry]):
+        labels (Mapping[str, str]):
             User-defined labels for the metastore
             service.
         network (str):
@@ -159,25 +157,74 @@ class Service(proto.Message):
         oneof="metastore_config",
         message="HiveMetastoreConfig",
     )
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    network = proto.Field(proto.STRING, number=7,)
-    endpoint_uri = proto.Field(proto.STRING, number=8,)
-    port = proto.Field(proto.INT32, number=9,)
-    state = proto.Field(proto.ENUM, number=10, enum=State,)
-    state_message = proto.Field(proto.STRING, number=11,)
-    artifact_gcs_uri = proto.Field(proto.STRING, number=12,)
-    tier = proto.Field(proto.ENUM, number=13, enum=Tier,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    network = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    endpoint_uri = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    port = proto.Field(
+        proto.INT32,
+        number=9,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=10,
+        enum=State,
+    )
+    state_message = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    artifact_gcs_uri = proto.Field(
+        proto.STRING,
+        number=12,
+    )
+    tier = proto.Field(
+        proto.ENUM,
+        number=13,
+        enum=Tier,
+    )
     maintenance_window = proto.Field(
-        proto.MESSAGE, number=15, message="MaintenanceWindow",
+        proto.MESSAGE,
+        number=15,
+        message="MaintenanceWindow",
+    )
+    uid = proto.Field(
+        proto.STRING,
+        number=16,
     )
-    uid = proto.Field(proto.STRING, number=16,)
     metadata_management_activity = proto.Field(
-        proto.MESSAGE, number=17, message="MetadataManagementActivity",
+        proto.MESSAGE,
+        number=17,
+        message="MetadataManagementActivity",
+    )
+    release_channel = proto.Field(
+        proto.ENUM,
+        number=19,
+        enum=ReleaseChannel,
     )
-    release_channel = proto.Field(proto.ENUM, number=19, enum=ReleaseChannel,)
 
 
 class MaintenanceWindow(proto.Message):
@@ -192,8 +239,16 @@ class MaintenanceWindow(proto.Message):
             The day of week, when the window starts.
     """
 
-    hour_of_day = proto.Field(proto.MESSAGE, number=1, message=wrappers_pb2.Int32Value,)
-    day_of_week = proto.Field(proto.ENUM, number=2, enum=dayofweek_pb2.DayOfWeek,)
+    hour_of_day = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=wrappers_pb2.Int32Value,
+    )
+    day_of_week = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=dayofweek_pb2.DayOfWeek,
+    )
 
 
 class HiveMetastoreConfig(proto.Message):
@@ -203,7 +258,7 @@ class HiveMetastoreConfig(proto.Message):
     Attributes:
         version (str):
             Immutable. The Hive metastore schema version.
-        config_overrides (Sequence[google.cloud.metastore_v1.types.HiveMetastoreConfig.ConfigOverridesEntry]):
+        config_overrides (Mapping[str, str]):
             A mapping of Hive metastore configuration key-value pairs to
             apply to the Hive metastore (configured in
             ``hive-site.xml``). The mappings override system defaults
@@ -217,9 +272,20 @@ class HiveMetastoreConfig(proto.Message):
             the request's ``service``.
     """
 
-    version = proto.Field(proto.STRING, number=1,)
-    config_overrides = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    kerberos_config = proto.Field(proto.MESSAGE, number=3, message="KerberosConfig",)
+    version = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    config_overrides = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    kerberos_config = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="KerberosConfig",
+    )
 
 
 class KerberosConfig(proto.Message):
@@ -241,9 +307,19 @@ class KerberosConfig(proto.Message):
             does not need to be named krb5.conf explicitly.
     """
 
-    keytab = proto.Field(proto.MESSAGE, number=1, message="Secret",)
-    principal = proto.Field(proto.STRING, number=2,)
-    krb5_config_gcs_uri = proto.Field(proto.STRING, number=3,)
+    keytab = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Secret",
+    )
+    principal = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    krb5_config_gcs_uri = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class Secret(proto.Message):
@@ -261,7 +337,11 @@ class Secret(proto.Message):
             This field is a member of `oneof`_ ``value``.
     """
 
-    cloud_secret = proto.Field(proto.STRING, number=2, oneof="value",)
+    cloud_secret = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="value",
+    )
 
 
 class MetadataManagementActivity(proto.Message):
@@ -277,9 +357,15 @@ class MetadataManagementActivity(proto.Message):
     """
 
     metadata_exports = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="MetadataExport",
+        proto.MESSAGE,
+        number=1,
+        message="MetadataExport",
+    )
+    restores = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="Restore",
     )
-    restores = proto.RepeatedField(proto.MESSAGE, number=2, message="Restore",)
 
 
 class MetadataImport(proto.Message):
@@ -344,20 +430,54 @@ class MetadataImport(proto.Message):
             MYSQL = 1
 
         database_type = proto.Field(
-            proto.ENUM, number=1, enum="MetadataImport.DatabaseDump.DatabaseType",
+            proto.ENUM,
+            number=1,
+            enum="MetadataImport.DatabaseDump.DatabaseType",
+        )
+        gcs_uri = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        type_ = proto.Field(
+            proto.ENUM,
+            number=4,
+            enum="DatabaseDumpSpec.Type",
         )
-        gcs_uri = proto.Field(proto.STRING, number=2,)
-        type_ = proto.Field(proto.ENUM, number=4, enum="DatabaseDumpSpec.Type",)
 
     database_dump = proto.Field(
-        proto.MESSAGE, number=6, oneof="metadata", message=DatabaseDump,
+        proto.MESSAGE,
+        number=6,
+        oneof="metadata",
+        message=DatabaseDump,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=State,
     )
-    name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    state = proto.Field(proto.ENUM, number=5, enum=State,)
 
 
 class MetadataExport(proto.Message):
@@ -392,12 +512,30 @@ class MetadataExport(proto.Message):
         FAILED = 3
         CANCELLED = 4
 
-    destination_gcs_uri = proto.Field(proto.STRING, number=4, oneof="destination",)
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    state = proto.Field(proto.ENUM, number=3, enum=State,)
+    destination_gcs_uri = proto.Field(
+        proto.STRING,
+        number=4,
+        oneof="destination",
+    )
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=State,
+    )
     database_dump_type = proto.Field(
-        proto.ENUM, number=5, enum="DatabaseDumpSpec.Type",
+        proto.ENUM,
+        number=5,
+        enum="DatabaseDumpSpec.Type",
     )
 
 
@@ -437,13 +575,38 @@ class Backup(proto.Message):
         FAILED = 4
         RESTORING = 5
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    state = proto.Field(proto.ENUM, number=4, enum=State,)
-    service_revision = proto.Field(proto.MESSAGE, number=5, message="Service",)
-    description = proto.Field(proto.STRING, number=6,)
-    restoring_services = proto.RepeatedField(proto.STRING, number=7,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=State,
+    )
+    service_revision = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="Service",
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    restoring_services = proto.RepeatedField(
+        proto.STRING,
+        number=7,
+    )
 
 
 class Restore(proto.Message):
@@ -485,12 +648,34 @@ class Restore(proto.Message):
         FULL = 1
         METADATA_ONLY = 2
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    state = proto.Field(proto.ENUM, number=3, enum=State,)
-    backup = proto.Field(proto.STRING, number=4,)
-    type_ = proto.Field(proto.ENUM, number=5, enum=RestoreType,)
-    details = proto.Field(proto.STRING, number=6,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=State,
+    )
+    backup = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    type_ = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=RestoreType,
+    )
+    details = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListServicesRequest(proto.Message):
@@ -530,11 +715,26 @@ class ListServicesRequest(proto.Message):
             order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListServicesResponse(proto.Message):
@@ -556,9 +756,19 @@ class ListServicesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    services = proto.RepeatedField(proto.MESSAGE, number=1, message="Service",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    services = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Service",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetServiceRequest(proto.Message):
@@ -573,7 +783,10 @@ class GetServiceRequest(proto.Message):
             ``projects/{project_number}/locations/{location_id}/services/{service_id}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateServiceRequest(proto.Message):
@@ -616,10 +829,23 @@ class CreateServiceRequest(proto.Message):
             supported.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    service_id = proto.Field(proto.STRING, number=2,)
-    service = proto.Field(proto.MESSAGE, number=3, message="Service",)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    service_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    service = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Service",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class UpdateServiceRequest(proto.Message):
@@ -659,10 +885,19 @@ class UpdateServiceRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
+    )
+    service = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Service",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    service = proto.Field(proto.MESSAGE, number=2, message="Service",)
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class DeleteServiceRequest(proto.Message):
@@ -693,8 +928,14 @@ class DeleteServiceRequest(proto.Message):
             supported.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ListMetadataImportsRequest(proto.Message):
@@ -734,11 +975,26 @@ class ListMetadataImportsRequest(proto.Message):
             order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListMetadataImportsResponse(proto.Message):
@@ -761,10 +1017,18 @@ class ListMetadataImportsResponse(proto.Message):
         return self
 
     metadata_imports = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="MetadataImport",
+        proto.MESSAGE,
+        number=1,
+        message="MetadataImport",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class GetMetadataImportRequest(proto.Message):
@@ -779,7 +1043,10 @@ class GetMetadataImportRequest(proto.Message):
             ``projects/{project_number}/locations/{location_id}/services/{service_id}/metadataImports/{import_id}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateMetadataImportRequest(proto.Message):
@@ -822,10 +1089,23 @@ class CreateMetadataImportRequest(proto.Message):
             supported.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    metadata_import_id = proto.Field(proto.STRING, number=2,)
-    metadata_import = proto.Field(proto.MESSAGE, number=3, message="MetadataImport",)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    metadata_import_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    metadata_import = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="MetadataImport",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class UpdateMetadataImportRequest(proto.Message):
@@ -865,10 +1145,19 @@ class UpdateMetadataImportRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
+    )
+    metadata_import = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="MetadataImport",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    metadata_import = proto.Field(proto.MESSAGE, number=2, message="MetadataImport",)
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class ListBackupsRequest(proto.Message):
@@ -908,11 +1197,26 @@ class ListBackupsRequest(proto.Message):
             order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListBackupsResponse(proto.Message):
@@ -934,9 +1238,19 @@ class ListBackupsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    backups = proto.RepeatedField(proto.MESSAGE, number=1, message="Backup",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    backups = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Backup",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetBackupRequest(proto.Message):
@@ -951,7 +1265,10 @@ class GetBackupRequest(proto.Message):
             ``projects/{project_number}/locations/{location_id}/services/{service_id}/backups/{backup_id}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateBackupRequest(proto.Message):
@@ -994,10 +1311,23 @@ class CreateBackupRequest(proto.Message):
             supported.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    backup_id = proto.Field(proto.STRING, number=2,)
-    backup = proto.Field(proto.MESSAGE, number=3, message="Backup",)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    backup_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    backup = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Backup",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class DeleteBackupRequest(proto.Message):
@@ -1028,8 +1358,14 @@ class DeleteBackupRequest(proto.Message):
             supported.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ExportMetadataRequest(proto.Message):
@@ -1073,11 +1409,23 @@ class ExportMetadataRequest(proto.Message):
             defaults to ``MYSQL``.
     """
 
-    destination_gcs_folder = proto.Field(proto.STRING, number=2, oneof="destination",)
-    service = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=3,)
+    destination_gcs_folder = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="destination",
+    )
+    service = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     database_dump_type = proto.Field(
-        proto.ENUM, number=4, enum="DatabaseDumpSpec.Type",
+        proto.ENUM,
+        number=4,
+        enum="DatabaseDumpSpec.Type",
     )
 
 
@@ -1116,10 +1464,23 @@ class RestoreServiceRequest(proto.Message):
             supported.
     """
 
-    service = proto.Field(proto.STRING, number=1,)
-    backup = proto.Field(proto.STRING, number=2,)
-    restore_type = proto.Field(proto.ENUM, number=3, enum="Restore.RestoreType",)
-    request_id = proto.Field(proto.STRING, number=4,)
+    service = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    backup = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    restore_type = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="Restore.RestoreType",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class OperationMetadata(proto.Message):
@@ -1152,13 +1513,36 @@ class OperationMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    status_message = proto.Field(proto.STRING, number=5,)
-    requested_cancellation = proto.Field(proto.BOOL, number=6,)
-    api_version = proto.Field(proto.STRING, number=7,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    status_message = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    requested_cancellation = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    api_version = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 class LocationMetadata(proto.Message):
@@ -1186,11 +1570,19 @@ class LocationMetadata(proto.Message):
                 that omits the ``version``.
         """
 
-        version = proto.Field(proto.STRING, number=1,)
-        is_default = proto.Field(proto.BOOL, number=2,)
+        version = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        is_default = proto.Field(
+            proto.BOOL,
+            number=2,
+        )
 
     supported_hive_metastore_versions = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=HiveMetastoreVersion,
+        proto.MESSAGE,
+        number=1,
+        message=HiveMetastoreVersion,
     )
 
 
