@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,14 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.metastore_v1beta.services.dataproc_metastore import pagers
-from google.cloud.metastore_v1beta.types import metastore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DataprocMetastoreTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
+
+from google.cloud.metastore_v1beta.services.dataproc_metastore import pagers
+from google.cloud.metastore_v1beta.types import metastore
+
 from .client import DataprocMetastoreClient
+from .transports.base import DEFAULT_CLIENT_INFO, DataprocMetastoreTransport
+from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
 
 
 class DataprocMetastoreAsyncClient:
@@ -251,11 +253,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_list_services():
+            async def sample_list_services():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.ListServicesRequest(
@@ -266,7 +275,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_services(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -329,12 +338,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServicesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -353,11 +370,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_get_service():
+            async def sample_get_service():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.GetServiceRequest(
@@ -365,7 +389,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_service(request=request)
+                response = await client.get_service(request=request)
 
                 # Handle the response
                 print(response)
@@ -427,7 +451,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -446,14 +475,20 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a metastore service in a project and
         location.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_create_service():
+            async def sample_create_service():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.CreateServiceRequest(
@@ -466,7 +501,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -559,7 +594,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -586,11 +626,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_update_service():
+            async def sample_update_service():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.UpdateServiceRequest(
@@ -601,7 +648,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -682,7 +729,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -708,11 +760,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_delete_service():
+            async def sample_delete_service():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.DeleteServiceRequest(
@@ -724,7 +783,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -763,9 +822,6 @@ class DataprocMetastoreAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -799,7 +855,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -825,11 +886,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_list_metadata_imports():
+            async def sample_list_metadata_imports():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.ListMetadataImportsRequest(
@@ -840,7 +908,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_metadata_imports(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -903,12 +971,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListMetadataImportsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -927,11 +1003,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_get_metadata_import():
+            async def sample_get_metadata_import():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.GetMetadataImportRequest(
@@ -939,7 +1022,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_metadata_import(request=request)
+                response = await client.get_metadata_import(request=request)
 
                 # Handle the response
                 print(response)
@@ -1001,7 +1084,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1020,14 +1108,20 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a new MetadataImport in a given project and
         location.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_create_metadata_import():
+            async def sample_create_metadata_import():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.CreateMetadataImportRequest(
@@ -1040,7 +1134,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1132,7 +1226,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1159,14 +1258,20 @@ class DataprocMetastoreAsyncClient:
         Only the description field of MetadataImport is
         supported to be updated.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_update_metadata_import():
+            async def sample_update_metadata_import():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.UpdateMetadataImportRequest(
@@ -1177,7 +1282,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1258,7 +1363,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1283,11 +1393,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_export_metadata():
+            async def sample_export_metadata():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.ExportMetadataRequest(
@@ -1300,7 +1417,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1342,7 +1459,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1369,11 +1491,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_restore_service():
+            async def sample_restore_service():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.RestoreServiceRequest(
@@ -1386,7 +1515,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1462,7 +1591,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1488,11 +1622,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_list_backups():
+            async def sample_list_backups():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.ListBackupsRequest(
@@ -1503,7 +1644,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_backups(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1566,12 +1707,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListBackupsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1590,11 +1739,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_get_backup():
+            async def sample_get_backup():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.GetBackupRequest(
@@ -1602,7 +1758,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_backup(request=request)
+                response = await client.get_backup(request=request)
 
                 # Handle the response
                 print(response)
@@ -1662,7 +1818,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1682,11 +1843,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_create_backup():
+            async def sample_create_backup():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.CreateBackupRequest(
@@ -1699,7 +1867,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1789,7 +1957,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1815,11 +1988,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
-            def sample_delete_backup():
+            async def sample_delete_backup():
                 # Create a client
-                client = metastore_v1beta.DataprocMetastoreClient()
+                client = metastore_v1beta.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1beta.DeleteBackupRequest(
@@ -1831,7 +2011,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1870,9 +2050,6 @@ class DataprocMetastoreAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1906,7 +2083,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
